##
##  wasm3.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         wasm3
Summary:      WebAssembly (WASM) Interpreter
URL:          https://github.com/wasm3/wasm3
Vendor:       Steven Massey, Volodymyr Shymanskyy
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Language
License:      MIT
Version:      0.5.0
Release:      20230623

#   list of sources
Source0:      https://github.com/wasm3/wasm3/archive/v%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes, cmake, make
PreReq:       OpenPKG, openpkg >= 20160101

%description
    WASM3 is a high performance WebAssembly (WASM) interpreter written
    in C. It is just 4-5x slower than state of the art WASM JIT engines
    (like Wasmer) and just 12x slower than native code execution.

%track
    prog wasm3 = {
        version   = %{version}
        url       = https://github.com/wasm3/wasm3/releases
        regex     = tree/v(\d+\.\d+\.\d+)
    }

%prep
    %setup -q

%build
    mkdir build
    cd build
    cmake \
        -Wno-dev \
        -DCMAKE_BUILD_TYPE="Release" \
        -DCMAKE_INSTALL_PREFIX="%{l_prefix}" \
        -DCMAKE_C_COMPILER="%{l_cc}" \
        -DCMAKE_C_FLAGS="%{l_cflags} %{l_cppflags}" \
        -DCMAKE_EXE_LINKER_FLAGS="%{l_ldflags}" \
        -DCMAKE_CXX_COMPILER="%{l_cxx}" \
        -DENABLE_SHARED=OFF \
        ..
    %{l_make} %{l_mflags}

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin
    %{l_shtool} install -c -s -m 775 \
        build/wasm3 $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

